Generates a value at risk (VaR) quantile based on the Lower Partial Moment ratio.
Value
Returns a numeric value representing the point at which "percentile" of the area of x is below.
Generates a value at risk (VaR) quantile based on the Lower Partial Moment ratio.
Returns a numeric value representing the point at which "percentile" of the area of x is below.