Generates an upside value at risk (VaR) quantile based on the Upper Partial Moment ratio
Value
Returns a numeric value representing the point at which "percentile" of the area of x is above.
Generates an upside value at risk (VaR) quantile based on the Upper Partial Moment ratio
Returns a numeric value representing the point at which "percentile" of the area of x is above.