View source: R/Partial_Moments.R
| Co.LPM_nD.batch | R Documentation |
Internal batched backend for evaluating Co.LPM_nD over many targets.
Co.LPM_nD.batch(data, targets, degree = 0, norm = TRUE)
data |
A numeric matrix with observations in rows and variables in columns. |
targets |
A numeric matrix with target rows and the same number of columns as data. |
degree |
numeric; degree for lower deviations. |
norm |
logical; normalize result. |
Numeric vector, one value per row of targets.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.