Internal batched backend for evaluating Co.LPM_nD over many targets.
Co.LPM_nD.batch(data, targets, degree = 0, norm = TRUE)Numeric vector, one value per row of targets.
A numeric matrix with observations in rows and variables in columns.
A numeric matrix with target rows and the same number of columns as data.
numeric; degree for lower deviations.
logical; normalize result.