Determines higher dimension dependence coefficients based on co-partial moment matrices ratios.
Arguments
- X
a numeric matrix or data frame.
- target
numeric; Typically the mean of Variable X for classical statistics equivalences, but does not have to be. (Vectorized)
(target = NULL)(default) will set the target as the mean of every variable.- continuous
logical;
TRUE(default) Generates a continuous measure using degree 1 PM.matrix, while discreteFALSEuses degree 0 PM.matrix.- plot
logical;
FALSE(default) Generates a 3d scatter plot with regression points.- independence.overlay
logical;
FALSE(default) Creates and overlays independent Co.LPM and Co.UPM regions to visually reference the difference in dependence from the data.frame of variables being analyzed. Under independence, the light green and red shaded areas would be occupied by green and red data points respectively.
References
Viole, F. (2016) "Beyond Correlation: Using the Elements of Variance for Conditional Means and Probabilities" doi:10.2139/ssrn.2745308 .