View source: R/Numerical_Differentiation.R
| NNS.diff | R Documentation |
Determines numerical derivative of a given univariate function using projected secant lines on the y-axis. These projected points infer finite steps h, in the finite step method.
NNS.diff(
f,
point,
h = abs(point) * 0.1 + 0.01,
tol = 1e-10,
max.iter = NULL,
digits = 12,
print.trace = FALSE,
plot = FALSE
)
f |
an expression or call or a formula with no lhs. |
point |
numeric; Point to be evaluated for derivative of a given function |
h |
numeric [0, ...]; Initial step for secant projection. Defaults to |
tol |
numeric; Sets the tolerance for the stopping condition of the inferred |
max.iter |
integer; |
digits |
numeric; Sets the number of digits specification of the output. Defaults to |
print.trace |
logical; |
plot |
logical; plots range, secant lines and y-intercept convergence. |
Returns a matrix of values, intercepts, derivatives, inferred step sizes for multiple methods of estimation.
Fred Viole, OVVO Financial Systems
Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments" (ISBN: 1490523995, 2nd edition: https://ovvo-financial.github.io/NNS/book/)
## Not run:
f <- function(x) sin(x) / x
NNS.diff(f, 4.1)
## Noisy function with explicit iteration cap
f_noisy <- function(x) sin(x) + rnorm(1, 0, 0.001)
NNS.diff(f_noisy, 1.0, max.iter = 100)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.