Seasonality test based on the coefficient of variation for the variable and lagged component series. A result of 1 signifies no seasonality present.
Arguments
- variable
a numeric vector.
- modulo
integer(s); NULL (default) Used to find the nearest multiple(s) in the reported seasonal period.
- mod.only
logical;
TRUE(default) Limits the number of seasonal periods returned to the specifiedmodulo.- plot
logical;
TRUE(default) Returns the plot of all periods exhibiting seasonality and the variable level reference.
Value
Returns a matrix of all periods exhibiting less coefficient of variation than the variable with "all.periods"; and the single period exhibiting the least coefficient of variation versus the variable with "best.period"; as well as a vector of "periods" for easy call into NNS.ARMA.optim. If no seasonality is detected, NNS.seas will return ("No Seasonality Detected").