Missing values (NA, Inf, NaN) are added at the end of the vector as the last bin returned if missinglast is set to TRUE
Arguments
- x
A matrix of regressor variables. Must have the same number of rows as the length of y.
- width
The width of the bins
- origin
The starting point for the bins. Any number smaller than origin will be disregarded
- missinglast
Boolean. Should the missing observations be added as a separate element at the end of the returned count vector.